---
title: '[공지] 관리자콘솔 결제내역 이슈 조치완료'
category: 공지사항
tags:
  - 공지사항
datetime: 2023-07-24T15:00:00.000Z
---

안녕하세요. 포트원 고객지원팀입니다.

현재 당사 관리자콘솔 조회가 느려지는 현상이 있었으며 긴급 조치하여 현재 이슈 해결완료되었습니다.

다시 한번 서비스 이용에 불편을 드려 죄송합니다.

**상세**

1. 장애 현상 : 포트원 관리자콘솔 상세내역조회시 정상적으로 조회가 이루어지지 않음
2. 장애 대상 : 관리자콘솔 결제내역 조회 및 관리자콘솔 내 취소

- 결제, 본인인증, API 취소시에는 이슈 없음

3\. 발생 시간 : 2023-07-25 13:00\~ 14:53 (조치완료)

감사합니다.
